==> haskell-constraints-extras-0.4.0.2-46.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints-extras
version:              0.4.0.2
visibility:           public
id:                   constraints-extras-0.4.0.2-ExpCytIK6glDi6nv6N5Ivc
key:                  constraints-extras-0.4.0.2-ExpCytIK6glDi6nv6N5Ivc
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  bedfb46e666d517b722c4839f55934b4
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.6.6/site-local/constraints-extras-0.4.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/constraints-extras-0.4.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/constraints-extras-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.2-ExpCytIK6glDi6nv6N5Ivc
depends:
    base-4.18.2.1 constraints-0.14.2-5Hasiz3qGyu5OkYwKIAmXY
    template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-extras-0.4.0.2-47-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints-extras
version:              0.4.0.2
visibility:           public
id:                   constraints-extras-0.4.0.2-KO66OA2DCdd7nSrKrNy5RA
key:                  constraints-extras-0.4.0.2-KO66OA2DCdd7nSrKrNy5RA
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  884a1682d8bad00ae1e05132e88ee274
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.6.6/site-local/constraints-extras-0.4.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/constraints-extras-0.4.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/constraints-extras-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.2-KO66OA2DCdd7nSrKrNy5RA
depends:
    base-4.18.2.1 constraints-0.14.2-HITsp0guL9Z2vC96u1IEz
    template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
